==> 0.0.1.tar.gz: ios/Classes/SwiftFlutterPlayerPlugin.swift <==
import Flutter
import UIKit
import AVFoundation

public class SwiftFlutterPlayerPlugin: NSObject, FlutterPlugin {
    
    var songPlayer = AVAudioPlayer()
    var hasBeenPaused = false

    var timer: Timer?
    
  public static func register(with registrar: FlutterPluginRegistrar) {
    let channel = FlutterMethodChannel(name: "flutter_player_plugin", binaryMessenger: registrar.messenger())
    let instance = SwiftFlutterPlayerPlugin()
    registrar.addMethodCallDelegate(instance, channel: channel)
  }

  public func handle(_ call: FlutterMethodCall, result: @escaping FlutterResult) {
    if call.method == "getPlatformVersion" {
        result("iOS " + UIDevice.current.systemVersion)
    } else if call.method == "loadFile" {
        do {
            songPlayer = try AVAudioPlayer(contentsOf: URL.init(fileURLWithPath: Bundle.main.path(forResource: "teste_wav", ofType: "wav")!))
            
            songPlayer.prepareToPlay()

            let audioSession = AVAudioSession.sharedInstance()
            do {
                try audioSession.setCategory(AVAudioSession.Category.playback)
            } catch let sessionError {
                print(sessionError)
            }
        } catch let songPlayerError {
            print(songPlayerError)
        }
    } else if call.method == "play" {
        songPlayer.play()
    } else if call.method == "pause" {
        songPlayer.pause()
    } else if call.method == "stop" {
        if let t = timer {
            t.invalidate()
            timer = nil
        }
        songPlayer.stop()
    } else if call.method == "play_loop" {
        if timer == nil {
            timer = Timer.scheduledTimer(timeInterval: 1.0,
                                        target: self,
                                        selector: #selector(self.play),
                                        userInfo: [ "foo" : "bar" ],
                                        repeats: true)
        }
    }
  }
}

==> 0.0.4.tar.gz: ios/Classes/SwiftFlutterPlayerPlugin.swift <==
import Flutter
import UIKit
import AVFoundation

public class SwiftFlutterPlayerPlugin: NSObject, FlutterPlugin {
    
    var songPlayer = AVAudioPlayer()
    var hasBeenPaused = false

    var timer: Timer?
    
  public static func register(with registrar: FlutterPluginRegistrar) {
    let channel = FlutterMethodChannel(name: "flutter_player_plugin", binaryMessenger: registrar.messenger())
    let instance = SwiftFlutterPlayerPlugin()
    registrar.addMethodCallDelegate(instance, channel: channel)
  }

  public func handle(_ call: FlutterMethodCall, result: @escaping FlutterResult) {
    if call.method == "getPlatformVersion" {
        result("iOS " + UIDevice.current.systemVersion)
    } else if call.method == "loadFile" {
        self.loadFile()
    } else if call.method == "play" {
        self.play()
    } else if call.method == "pause" {
        self.pause()
    } else if call.method == "stop" {
        self.stop()
    } else if call.method == "play_loop" {
        self.play_loop()
    }
  }
    
    func loadFile() {
        do {
            songPlayer = try AVAudioPlayer(contentsOf: URL.init(fileURLWithPath: Bundle.main.path(forResource: "teste_wav", ofType: "wav")!))
            
            songPlayer.prepareToPlay()

            let audioSession = AVAudioSession.sharedInstance()
            do {
                try audioSession.setCategory(AVAudioSessionCategoryPlayback)
            } catch let sessionError {
                print(sessionError)
            }
        } catch let songPlayerError {
            print(songPlayerError)
        }
    }
    
    @objc func play() {
        songPlayer.play()
    }
    
    func pause() {
        songPlayer.pause()
    }
    
    func stop() {
        if let t = timer {
            t.invalidate()
            timer = nil
        }
        songPlayer.stop()
    }
    
    func play_loop() {
        if timer == nil {
            timer = Timer.scheduledTimer(timeInterval: 1.0,
                                        target: self,
                                        selector: #selector(self.play),
                                        userInfo: [ "foo" : "bar" ],
                                        repeats: true)
        }
    }
}
